OpenCRAVAT Variant Report
Type a variant and enter or click the Update annotation button. The syntax of a variant is chromosome, position, reference allele, and alternate allele, concatenated with a colon. Strand is assumed to be plus. For example, chr17:39724004:C:G
Variant Annotations
Cancer
Population Allele Frequencies
Clinical Relevance
Gene
Pathogenicity Prediction
Evolutionary Constraint

Noncoding and Genomic Elements | Interactions

Visualization